---
title: species
sidebarTitle: species
---

# `catalax.model.species`

## Classes

### `Species` <sup><a href="https://github.com/JR-1991/Catalax/blob/master/catalax/model/species.py#L7" target="_blank"><Icon icon="github" style="width: 14px; height: 14px;" /></a></sup>

**Methods:**

#### `convert_string_species_to_sympy` <sup><a href="https://github.com/JR-1991/Catalax/blob/master/catalax/model/species.py#L16" target="_blank"><Icon icon="github" style="width: 14px; height: 14px;" /></a></sup>

```python
convert_string_species_to_sympy(cls, value)
```

Converts given strings of unit definitions into SymPy symbols

